package com.hw.wms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.wms.domain.WmsTransfer;
import com.hw.wms.service.IWmsTransferService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 转库记录Controller
 * 
 * @author xins
 * @date 2024-01-12
 */
@RestController
@RequestMapping("/transfer")
public class WmsTransferController extends BaseController
{
    @Autowired
    private IWmsTransferService wmsTransferService;

    /**
     * 查询转库记录列表
     */
    @RequiresPermissions("wms:transfer:list")
    @GetMapping("/list")
    public TableDataInfo list(WmsTransfer wmsTransfer)
    {
        startPage();
        List<WmsTransfer> list = wmsTransferService.selectWmsTransferList(wmsTransfer);
        return getDataTable(list);
    }

    /**
     * 导出转库记录列表
     */
    @RequiresPermissions("wms:transfer:export")
    @Log(title = "转库记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WmsTransfer wmsTransfer)
    {
        List<WmsTransfer> list = wmsTransferService.selectWmsTransferList(wmsTransfer);
        ExcelUtil<WmsTransfer> util = new ExcelUtil<WmsTransfer>(WmsTransfer.class);
        util.exportExcel(response, list, "转库记录数据");
    }

    /**
     * 获取转库记录详细信息
     */
    @RequiresPermissions("wms:transfer:query")
    @GetMapping(value = "/{transferId}")
    public AjaxResult getInfo(@PathVariable("transferId") Long transferId)
    {
        return success(wmsTransferService.selectWmsTransferByTransferId(transferId));
    }

    /**
     * 新增转库记录
     */
    @RequiresPermissions("wms:transfer:add")
    @Log(title = "转库记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WmsTransfer wmsTransfer)
    {
        return toAjax(wmsTransferService.insertWmsTransfer(wmsTransfer));
    }

    /**
     * 修改转库记录
     */
    @RequiresPermissions("wms:transfer:edit")
    @Log(title = "转库记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WmsTransfer wmsTransfer)
    {
        return toAjax(wmsTransferService.updateWmsTransfer(wmsTransfer));
    }

    /**
     * 删除转库记录
     */
    @RequiresPermissions("wms:transfer:remove")
    @Log(title = "转库记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{transferIds}")
    public AjaxResult remove(@PathVariable Long[] transferIds)
    {
        return toAjax(wmsTransferService.deleteWmsTransferByTransferIds(transferIds));
    }
}
